@@ -1040,6 +1040,20 @@ class Sf:
         """
         getattr(self.sf.mdapi, metadata_type).rename(previous_name, new_name)
     
+    ### ----------------------------------------------------------------------------------------------------
+    ### Custom Tooling API Methods
+    ### ----------------------------------------------------------------------------------------------------
+    
+    def tooling_query_all(self, query):
+        done = False
+        full_results = []
+        result = self.sf_api_call('/services/data/v52.0/tooling/query', method='get', parameters={'q': query})
+        while not done:
+            full_results.extend(result['records'])
+            done = result['done']
+            if not done:
+                result = self.sf_api_call(result['nextRecordsUrl'])
+        return full_results
 
     ### ----------------------------------------------------------------------------------------------------
     ### Utility Functions
@@ -1055,9 +1069,9 @@ class Sf:
             'Accept-Encoding': 'gzip',
             'Authorization': 'Bearer %s' % self.session_id
         }
-        if method == 'get':
+        if method.lower() == 'get':
             r = requests.request(method, 'https://'+self.instance+action, headers=headers, params=parameters, timeout=30)
-        elif method in ['post', 'patch']:
+        elif method.lower() in ['post', 'patch']:
             r = requests.request(method, 'https://'+self.instance+action, headers=headers, json=data, params=parameters, timeout=10)
         else:
             # other methods not implemented in this example
